from setuptools import setup
setup(
  name = 'randprox', 
  version = '1.3',      
  license='MIT',        
  description = 'Get Random Proxy',   
  author = 'KattStof',                   
  author_email = 'Kattstof@autistici.org',      
  url = 'https://github.com/kattstof',
  requires=['random', 'requests'],
  download_url = 'https://github.com/kattstof/RandProx', 
  keywords = ['proxy'],  
  classifiers=[
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3',
  ],
)
